@@ -389,6 +389,10 @@ public:
          * as a percentage of scrollbar length
          */
         MarkerSize,
+        /** (QColor) Color for scrollbar result highlighting lines */
+        SearchLineColor,
+        /** (int) Alpha value - Opacity for the search lines */
+        SearchLineOpacity,
         /** When to show line numbers.
          * 0 for Never, 1 when showing URL hints, 2 for always
          */
@@ -509,7 +513,7 @@ public:
     bool isEmpty() const;
 
     /**
-     * Clears all set properties in this profile. Afte calling this, isEmpty()
+     * Clears all set properties in this profile. After calling this, isEmpty()
      * will return true.
      */
     void clear()
