@@ -25,10 +25,10 @@ TerminalColor::TerminalColor(QObject *parent)
     setColorTable(ColorScheme::defaultTable);
 }
 
-void TerminalColor::applyProfile(const Profile::Ptr &profile, const std::shared_ptr<const ColorScheme> &colorScheme, uint randomSeed)
+void TerminalColor::applyProfile(const Profile::Ptr &profile, const std::shared_ptr<const ColorScheme> &colorScheme, uint sessionId)
 {
     QColor table[TABLE_COLORS];
-    colorScheme->getColorTable(table, randomSeed);
+    colorScheme->getColorTable(table, sessionId);
     setColorTable(table);
     setOpacity(colorScheme->opacity());
 
